/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Linky installer
 *
 * The Initial Developer of the Original Code is Henrik Gemal.
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Henrik Gemal <linky@gemal.dk> http://gemal.dk
 *   Matthew Wilson <matthew@mjwilson.demon.co.uk>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const myProductName = "wbmpsupport";
const myProductRegKey = "wbmpsupport";
const myProductRegVersion = "0.1";
const myProductRegVersionBuild = "20040411";
const myComponentFileName = "imgwbmp.dll";
const myComponentFileSize = 228;

// global settings
// dont change these
const sysComponents = getFolder("Components");
const errPage = "http://devedge.netscape.com/library/manuals/2001/xpinstall/1.0/err.html";

// verify disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired) {
    var spaceAvailable = fileGetDiskSpaceAvailable(dirPath);
    if (parseInt(spaceAvailable/1024) < spaceRequired) {
        logComment("Insufficient disk space: " + dirPath + "\n\trequired : " + spaceRequired + " K\n\tavailable: " + spaceAvailable + " K");
        return(false);
    } else {
        return(true);
    }
}

// did the user cancel?
var err;
var err_tmp;

// have we already given an error pop-up to the user?
var alerted = false;

// init the installation
err_tmp = initInstall(myProductName, myProductRegKey, myProductRegVersion + "." + myProductRegVersionBuild);
if (err_tmp) {
    err = err_tmp;
}

logComment(myProductName + " version " + myProductRegVersion + " being installed on " + buildID);

if (!err && !verifyDiskSpace(sysComponents, myComponentFileSize)) {
    err = INSUFFICIENT_DISK_SPACE;
}

// add the component
if (!err) {
    err_tmp = addFile(myProductName, myComponentFileName, sysComponents, "");
    if (err_tmp) {
        logComment("Problem adding component. Error code: " + err_tmp);
        if (!alerted) { // Don't annoy the user a second time
            window.alert ("There was a problem installing WBMP support.\n(Maybe you don't have the correct permissions.)");
        }
        alerted = true;
        err = err_tmp;
    } else {
        logComment("OK adding component.");
    }
}

// do the install
if (!err) {
    err_tmp = performInstall();
    if (err_tmp < 0) {
        logComment("Problem performing install. Error code: " + err_tmp);
        err = err_tmp;
    } else {
        alert(myProductName + " version " + myProductRegVersion + " has been successfully installed!\nYou must restart your browser to complete installation.");
    }
}

// did it work?
if (err) {
    logComment("Problem installing. Error code: " + err + ". Error codes can been seen at: " + errPage);
    alert(myProductName + " version " + myProductRegVersion + " was not installed!\nError code: " + err + "\n\nError codes can been seen at:\n" + errPage);
    cancelInstall(err);
}
